@@ -29,7 +29,7 @@ def check_type(actual, definition):
     # Currently support list, set, dict and union
     if hasattr(definition, "__origin__"):
         if hasattr(actual, "__origin__"):
-            return actual.__origin__ == definition.__origin__ and all(
+            return issubclass(actual.__origin__, definition.__origin__) and all(
                 check_type(actual.__args__[i], definition.__args__[i])
                 for i in range(len(actual.__args__))
             )
